@@ -332,8 +332,7 @@ int cgiMain() {
     return -1;
   }
 
-  if(rfid_cgi.verbose == 3)
-    rfid.verbose = 3;
+  rfid.verbose = rfid_cgi.verbose;
 
   if(rfid_init(&rfid, driver, device) < 0) {
     report_error(&rfid, "rfid_init");
@@ -341,10 +340,7 @@ int cgiMain() {
   }
   
   if(option_read) {
-    if(signal(SIGALRM, keepalive) < 0) {
-      perror("signal");
-      return -1;
-    }
+    signal(SIGALRM, keepalive);
 
     retval = read_daemon(&rfid_cgi);
   } else if(option_write) {
